@@ -9,20 +9,35 @@ Copyright Contributors to the Zincware Project.
 Description: Standard python init file for the main directory
 """
 
-from .dvc import DVC
-import zntrack.dvc
-from .core.decorator import Node
-from .project import ZnTrackProject
-from .interface import DVCInterface
-from .utils import config
-
 import logging
 import sys
 
+import znjson
+
+import zntrack.dvc
+
+from .core.decorator import Node
+from .dvc import DVC
+from .interface import DVCInterface
+from .project import ZnTrackProject
+from .utils import config
+from .utils.serializer import ZnTrackStageConverter, ZnTrackTypeConverter
+
+# register converters
+znjson.config.ACTIVE_CONVERTER = [
+    ZnTrackTypeConverter,
+    ZnTrackStageConverter,
+    znjson.PathlibConverter,
+]
+try:
+    znjson.register(znjson.NumpyConverter)
+except AttributeError:
+    pass
+
 #
 __all__ = ["Node", "ZnTrackProject", "DVCInterface", "DVC", "config", "dvc"]
 
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
